@@ -1,6 +1,6 @@
 # LP: #1560134
 
-cd $ADTTMP
+cd $AUTOPKGTEST_TMP
 
 cat > relative.py <<EOF
 from . import foo
